@@ -137,15 +137,16 @@ pixbuf_document_set_page_offset (EvDocument  *document,
 
 static void
 pixbuf_document_get_page_size (EvDocument   *document,
+			       int           page,
 			       int          *width,
 			       int          *height)
 {
 	PixbufDocument *pixbuf_document = PIXBUF_DOCUMENT (document);
 
 	if (width)
-		*width = gdk_pixbuf_get_width (pixbuf_document->pixbuf);
+		*width = gdk_pixbuf_get_width (pixbuf_document->pixbuf) * pixbuf_document->scale;
 	if (height)
-		*height = gdk_pixbuf_get_height (pixbuf_document->pixbuf);
+		*height = gdk_pixbuf_get_height (pixbuf_document->pixbuf) * pixbuf_document->scale;
 }
 
 static void
@@ -156,37 +157,28 @@ pixbuf_document_render (EvDocument  *document,
 			int          clip_height)
 {
 	PixbufDocument *pixbuf_document = PIXBUF_DOCUMENT (document);
+	GdkPixbuf *tmp_pixbuf;
+	
+	tmp_pixbuf = gdk_pixbuf_new (gdk_pixbuf_get_colorspace (pixbuf_document->pixbuf),
+				     gdk_pixbuf_get_has_alpha (pixbuf_document->pixbuf),
+				     gdk_pixbuf_get_bits_per_sample (pixbuf_document->pixbuf),
+				     clip_width, clip_height);
+	
+	gdk_pixbuf_fill (tmp_pixbuf, 0xffffffff);
+	gdk_pixbuf_scale (pixbuf_document->pixbuf, tmp_pixbuf, 0, 0,
+			  MIN(gdk_pixbuf_get_width(pixbuf_document->pixbuf)* pixbuf_document->scale-clip_x, clip_width),
+			  MIN(gdk_pixbuf_get_height(pixbuf_document->pixbuf)* pixbuf_document->scale-clip_y, clip_height),
+			  -clip_x, -clip_y,
+			  pixbuf_document->scale, pixbuf_document->scale,
+			  GDK_INTERP_BILINEAR);
+	
+	gdk_draw_pixbuf (pixbuf_document->target, NULL, tmp_pixbuf,
+			 0, 0,
+			 clip_x, clip_y,
+			 clip_width, clip_height, GDK_RGB_DITHER_NORMAL,
+			 0, 0);
 
-	if (pixbuf_document->scale == 1.0) {
- 		gdk_draw_pixbuf (pixbuf_document->target, NULL, pixbuf_document->pixbuf,
-				 clip_x, clip_y,
-				 clip_x, clip_y,
-				 clip_width, clip_height, GDK_RGB_DITHER_NORMAL,
-				 0, 0);
-	}
-	else {
-		GdkPixbuf *tmp_pixbuf;
-
-		tmp_pixbuf = gdk_pixbuf_new (gdk_pixbuf_get_colorspace (pixbuf_document->pixbuf),
-					     gdk_pixbuf_get_has_alpha (pixbuf_document->pixbuf),
-					     gdk_pixbuf_get_bits_per_sample (pixbuf_document->pixbuf),
-					     clip_width, clip_height);
-
-		gdk_pixbuf_scale (pixbuf_document->pixbuf, tmp_pixbuf, 0, 0, clip_width, clip_height,
-				  clip_x * pixbuf_document->scale,
-				  clip_y * pixbuf_document->scale,
-				  pixbuf_document->scale, pixbuf_document->scale,
-				  GDK_INTERP_BILINEAR);
-		
- 		gdk_draw_pixbuf (pixbuf_document->target, NULL, tmp_pixbuf,
-				 0, 0,
-				 clip_x + pixbuf_document->x_offset,
-				 clip_y + pixbuf_document->y_offset,
-				 clip_width, clip_height, GDK_RGB_DITHER_NORMAL,
-				 0, 0);
-
-		g_object_unref (tmp_pixbuf);
-	}
+	g_object_unref (tmp_pixbuf);
 }
 
 static void
@@ -275,19 +267,20 @@ pixbuf_document_document_iface_init (EvDocumentIface *iface)
 
 static GdkPixbuf *
 pixbuf_document_thumbnails_get_thumbnail (EvDocumentThumbnails   *document,
-					  gint 			 page,
-					  gint			 width)
+					  gint 			  page,
+					  gint			  size,
+					  gboolean                border)
 {
 	PixbufDocument *pixbuf_document = PIXBUF_DOCUMENT (document);
 	GdkPixbuf *pixbuf;
 	gdouble scale_factor;
 	gint height;
 	
-	scale_factor = (gdouble)width / gdk_pixbuf_get_width (pixbuf_document->pixbuf);
+	scale_factor = (gdouble)size / gdk_pixbuf_get_width (pixbuf_document->pixbuf);
 
 	height = gdk_pixbuf_get_height (pixbuf_document->pixbuf) * scale_factor;
 	
-	pixbuf = gdk_pixbuf_scale_simple (pixbuf_document->pixbuf, width, height,
+	pixbuf = gdk_pixbuf_scale_simple (pixbuf_document->pixbuf, size, height,
 					  GDK_INTERP_BILINEAR);
 	
 	return pixbuf;
@@ -322,6 +315,6 @@ pixbuf_document_init (PixbufDocument *pixbuf_document)
 {
 	pixbuf_document->scale = 1.0;
 
-	pixbuf_document->x_offset = 10;
-	pixbuf_document->y_offset = 10;
+	pixbuf_document->x_offset = 0;
+	pixbuf_document->y_offset = 0;
 }
